@@ -17,7 +17,8 @@
 from __future__ import annotations
 
 import time
-from typing import TYPE_CHECKING, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.cloud.dataform_v1beta1 import DataformClient
@@ -41,14 +42,6 @@ if TYPE_CHECKING:
 class DataformHook(GoogleBaseHook):
     """Hook for Google Cloud DataForm APIs."""
 
-    def __init__(self, **kwargs):
-        if kwargs.get("delegate_to") is not None:
-            raise RuntimeError(
-                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
-                " of Google Provider. You MUST convert it to `impersonate_chain`"
-            )
-        super().__init__(**kwargs)
-
     def get_dataform_client(self) -> DataformClient:
         """Retrieve client library object that allow access to Cloud Dataform service."""
         return DataformClient(credentials=self.get_credentials())
@@ -663,7 +656,8 @@ class DataformHook(GoogleBaseHook):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> InstallNpmPackagesResponse:
-        """Install NPM dependencies in the provided workspace.
+        """
+        Install NPM dependencies in the provided workspace.
 
         Requires "package.json" to be created in the workspace.
 
