@@ -20,7 +20,8 @@
 from __future__ import annotations
 
 import asyncio
-from typing import TYPE_CHECKING, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING
 
 from google.api_core.client_options import ClientOptions
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -46,14 +47,10 @@ class BatchPredictionJobHook(GoogleBaseHook):
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
-        if kwargs.get("delegate_to") is not None:
-            raise RuntimeError(
-                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
-                " of Google Provider. You MUST convert it to `impersonate_chain`"
-            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             impersonation_chain=impersonation_chain,
+            **kwargs,
         )
         self._batch_prediction_job: BatchPredictionJob | None = None
 
@@ -551,7 +548,8 @@ class BatchPredictionJobAsyncHook(GoogleBaseAsyncHook):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> types.BatchPredictionJob:
-        """Retrieve a batch prediction tuning job.
+        """
+        Retrieve a batch prediction tuning job.
 
         :param project_id: Required. The ID of the Google Cloud project that the job belongs to.
         :param location: Required. The ID of the Google Cloud region that the job belongs to.
