@@ -20,19 +20,23 @@ from __future__ import annotations
 import copy
 import json
 import traceback
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 if TYPE_CHECKING:
-    from openlineage.client.facet import (
-        BaseFacet,
+    from airflow.providers.common.compat.openlineage.facet import (
+        Dataset,
+        InputDataset,
+        OutputDataset,
         OutputStatisticsOutputDatasetFacet,
+        RunFacet,
         SchemaDatasetFacet,
     )
-    from openlineage.client.run import Dataset
-
     from airflow.providers.google.cloud.openlineage.utils import BigQueryJobRunFacet
 
 
+BIGQUERY_NAMESPACE = "bigquery"
+
+
 class _BigQueryOpenLineageMixin:
     def get_openlineage_facets_on_complete(self, _):
         """
@@ -61,8 +65,7 @@ class _BigQueryOpenLineageMixin:
             - SchemaDatasetFacet
             - OutputStatisticsOutputDatasetFacet
         """
-        from openlineage.client.facet import ExternalQueryRunFacet, SqlJobFacet
-
+        from airflow.providers.common.compat.openlineage.facet import ExternalQueryRunFacet, SQLJobFacet
         from airflow.providers.openlineage.extractors import OperatorLineage
         from airflow.providers.openlineage.sqlparser import SQLParser
 
@@ -79,13 +82,13 @@ class _BigQueryOpenLineageMixin:
                 impersonation_chain=self.impersonation_chain,
             )
 
-        run_facets: dict[str, BaseFacet] = {
+        run_facets: dict[str, RunFacet] = {
             "externalQuery": ExternalQueryRunFacet(externalQueryId=self.job_id, source="bigquery")
         }
 
-        job_facets = {"sql": SqlJobFacet(query=SQLParser.normalize_sql(self.sql))}
+        job_facets = {"sql": SQLJobFacet(query=SQLParser.normalize_sql(self.sql))}
 
-        self.client = self.hook.get_client(project_id=self.hook.project_id)
+        self.client = self.hook.get_client(project_id=self.hook.project_id, location=self.location)
         job_ids = self.job_id
         if isinstance(self.job_id, str):
             job_ids = [self.job_id]
@@ -104,16 +107,12 @@ class _BigQueryOpenLineageMixin:
         )
 
     def get_facets(self, job_id: str):
-        from openlineage.client.facet import ErrorMessageRunFacet
-
-        from airflow.providers.google.cloud.openlineage.utils import (
-            BigQueryErrorRunFacet,
-            get_from_nullable_chain,
-        )
+        from airflow.providers.common.compat.openlineage.facet import ErrorMessageRunFacet
+        from airflow.providers.google.cloud.openlineage.utils import get_from_nullable_chain
 
         inputs = []
         outputs = []
-        run_facets: dict[str, BaseFacet] = {}
+        run_facets: dict[str, RunFacet] = {}
         if hasattr(self, "log"):
             self.log.debug("Extracting data from bigquery job: `%s`", job_id)
         try:
@@ -123,8 +122,7 @@ class _BigQueryOpenLineageMixin:
             if get_from_nullable_chain(props, ["status", "state"]) != "DONE":
                 raise ValueError(f"Trying to extract data from running bigquery job: `{job_id}`")
 
-            # TODO: remove bigQuery_job in next release
-            run_facets["bigQuery_job"] = run_facets["bigQueryJob"] = self._get_bigquery_job_run_facet(props)
+            run_facets["bigQueryJob"] = self._get_bigquery_job_run_facet(props)
 
             if get_from_nullable_chain(props, ["statistics", "numChildJobs"]):
                 if hasattr(self, "log"):
@@ -143,22 +141,18 @@ class _BigQueryOpenLineageMixin:
             if hasattr(self, "log"):
                 self.log.warning("Cannot retrieve job details from BigQuery.Client. %s", e, exc_info=True)
             exception_msg = traceback.format_exc()
-            # TODO: remove BigQueryErrorRunFacet in next release
             run_facets.update(
                 {
                     "errorMessage": ErrorMessageRunFacet(
                         message=f"{e}: {exception_msg}",
                         programmingLanguage="python",
-                    ),
-                    "bigQuery_error": BigQueryErrorRunFacet(
-                        clientError=f"{e}: {exception_msg}",
-                    ),
+                    )
                 }
             )
         deduplicated_outputs = self._deduplicate_outputs(outputs)
         return inputs, deduplicated_outputs, run_facets
 
-    def _deduplicate_outputs(self, outputs: list[Dataset | None]) -> list[Dataset]:
+    def _deduplicate_outputs(self, outputs: list[OutputDataset | None]) -> list[OutputDataset]:
         # Sources are the same so we can compare only names
         final_outputs = {}
         for single_output in outputs:
@@ -171,22 +165,26 @@ class _BigQueryOpenLineageMixin:
 
             # No OutputStatisticsOutputDatasetFacet is added to duplicated outputs as we can not determine
             # if the rowCount or size can be summed together.
-            single_output.facets.pop("outputStatistics", None)
+            if single_output.outputFacets:
+                single_output.outputFacets.pop("outputStatistics", None)
             final_outputs[key] = single_output
 
         return list(final_outputs.values())
 
-    def _get_inputs_outputs_from_job(self, properties: dict) -> tuple[list[Dataset], Dataset | None]:
+    def _get_inputs_outputs_from_job(
+        self, properties: dict
+    ) -> tuple[list[InputDataset], OutputDataset | None]:
         from airflow.providers.google.cloud.openlineage.utils import get_from_nullable_chain
 
         input_tables = get_from_nullable_chain(properties, ["statistics", "query", "referencedTables"]) or []
         output_table = get_from_nullable_chain(properties, ["configuration", "query", "destinationTable"])
-        inputs = [self._get_dataset(input_table) for input_table in input_tables]
+        inputs = [(self._get_input_dataset(input_table)) for input_table in input_tables]
         if output_table:
-            output = self._get_dataset(output_table)
+            output = self._get_output_dataset(output_table)
             dataset_stat_facet = self._get_statistics_dataset_facet(properties)
+            output.outputFacets = output.outputFacets or {}
             if dataset_stat_facet:
-                output.facets.update({"outputStatistics": dataset_stat_facet})
+                output.outputFacets["outputStatistics"] = dataset_stat_facet
 
         return inputs, output
 
@@ -210,9 +208,10 @@ class _BigQueryOpenLineageMixin:
         )
 
     @staticmethod
-    def _get_statistics_dataset_facet(properties) -> OutputStatisticsOutputDatasetFacet | None:
-        from openlineage.client.facet import OutputStatisticsOutputDatasetFacet
-
+    def _get_statistics_dataset_facet(
+        properties,
+    ) -> OutputStatisticsOutputDatasetFacet | None:
+        from airflow.providers.common.compat.openlineage.facet import OutputStatisticsOutputDatasetFacet
         from airflow.providers.google.cloud.openlineage.utils import get_from_nullable_chain
 
         query_plan = get_from_nullable_chain(properties, chain=["statistics", "query", "queryPlan"])
@@ -226,10 +225,18 @@ class _BigQueryOpenLineageMixin:
             return OutputStatisticsOutputDatasetFacet(rowCount=int(out_rows), size=int(out_bytes))
         return None
 
-    def _get_dataset(self, table: dict) -> Dataset:
-        from openlineage.client.run import Dataset
+    def _get_input_dataset(self, table: dict) -> InputDataset:
+        from airflow.providers.common.compat.openlineage.facet import InputDataset
 
-        BIGQUERY_NAMESPACE = "bigquery"
+        return cast(InputDataset, self._get_dataset(table, "input"))
+
+    def _get_output_dataset(self, table: dict) -> OutputDataset:
+        from airflow.providers.common.compat.openlineage.facet import OutputDataset
+
+        return cast(OutputDataset, self._get_dataset(table, "output"))
+
+    def _get_dataset(self, table: dict, dataset_type: str) -> Dataset:
+        from airflow.providers.common.compat.openlineage.facet import InputDataset, OutputDataset
 
         project = table.get("projectId")
         dataset = table.get("datasetId")
@@ -237,15 +244,30 @@ class _BigQueryOpenLineageMixin:
         dataset_name = f"{project}.{dataset}.{table_name}"
 
         dataset_schema = self._get_table_schema_safely(dataset_name)
-        return Dataset(
-            namespace=BIGQUERY_NAMESPACE,
-            name=dataset_name,
-            facets={
-                "schema": dataset_schema,
-            }
-            if dataset_schema
-            else {},
-        )
+        if dataset_type == "input":
+            # Logic specific to creating InputDataset (if needed)
+            return InputDataset(
+                namespace=BIGQUERY_NAMESPACE,
+                name=dataset_name,
+                facets={
+                    "schema": dataset_schema,
+                }
+                if dataset_schema
+                else {},
+            )
+        elif dataset_type == "output":
+            # Logic specific to creating OutputDataset (if needed)
+            return OutputDataset(
+                namespace=BIGQUERY_NAMESPACE,
+                name=dataset_name,
+                facets={
+                    "schema": dataset_schema,
+                }
+                if dataset_schema
+                else {},
+            )
+        else:
+            raise ValueError("Invalid dataset_type. Must be 'input' or 'output'")
 
     def _get_table_schema_safely(self, table_name: str) -> SchemaDatasetFacet | None:
         try:
@@ -256,8 +278,10 @@ class _BigQueryOpenLineageMixin:
         return None
 
     def _get_table_schema(self, table: str) -> SchemaDatasetFacet | None:
-        from openlineage.client.facet import SchemaDatasetFacet, SchemaField
-
+        from airflow.providers.common.compat.openlineage.facet import (
+            SchemaDatasetFacet,
+            SchemaDatasetFacetFields,
+        )
         from airflow.providers.google.cloud.openlineage.utils import get_from_nullable_chain
 
         bq_table = self.client.get_table(table)
@@ -271,7 +295,7 @@ class _BigQueryOpenLineageMixin:
 
         return SchemaDatasetFacet(
             fields=[
-                SchemaField(
+                SchemaDatasetFacetFields(
                     name=field.get("name"),
                     type=field.get("type"),
                     description=field.get("description"),
