@@ -21,8 +21,9 @@ from __future__ import annotations
 
 import json
 import re
+from collections.abc import Sequence
 from copy import deepcopy
-from typing import TYPE_CHECKING, Any, Sequence
+from typing import TYPE_CHECKING, Any
 from urllib.parse import unquote, urlsplit
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -40,6 +41,7 @@ from airflow.providers.google.cloud.links.cloud_build import (
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.triggers.cloud_build import CloudBuildCreateBuildTrigger
 from airflow.providers.google.common.consts import GOOGLE_DEFAULT_DEFERRABLE_METHOD_NAME
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 from airflow.utils import yaml
 from airflow.utils.helpers import exactly_one
 
@@ -87,7 +89,7 @@ class CloudBuildCancelBuildOperator(GoogleCloudBaseOperator):
         self,
         *,
         id_: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -171,7 +173,7 @@ class CloudBuildCreateBuildOperator(GoogleCloudBaseOperator):
         self,
         *,
         build: dict | Build,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -316,7 +318,7 @@ class CloudBuildCreateBuildTriggerOperator(GoogleCloudBaseOperator):
         self,
         *,
         trigger: dict | BuildTrigger,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -399,7 +401,7 @@ class CloudBuildDeleteBuildTriggerOperator(GoogleCloudBaseOperator):
         self,
         *,
         trigger_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -473,7 +475,7 @@ class CloudBuildGetBuildOperator(GoogleCloudBaseOperator):
         self,
         *,
         id_: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -549,7 +551,7 @@ class CloudBuildGetBuildTriggerOperator(GoogleCloudBaseOperator):
         self,
         *,
         trigger_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -627,7 +629,7 @@ class CloudBuildListBuildTriggersOperator(GoogleCloudBaseOperator):
         self,
         *,
         location: str = "global",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         page_size: int | None = None,
         page_token: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
@@ -707,7 +709,7 @@ class CloudBuildListBuildsOperator(GoogleCloudBaseOperator):
         self,
         *,
         location: str = "global",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         page_size: int | None = None,
         filter_: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
@@ -783,7 +785,7 @@ class CloudBuildRetryBuildOperator(GoogleCloudBaseOperator):
         self,
         *,
         id_: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -868,7 +870,7 @@ class CloudBuildRunBuildTriggerOperator(GoogleCloudBaseOperator):
         *,
         trigger_id: str,
         source: dict | RepoSource,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -953,7 +955,7 @@ class CloudBuildUpdateBuildTriggerOperator(GoogleCloudBaseOperator):
         *,
         trigger_id: str,
         trigger: dict | BuildTrigger,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
