@@ -19,7 +19,8 @@
 from __future__ import annotations
 
 import time
-from typing import TYPE_CHECKING, Any, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Any
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.triggers.dataplex import (
@@ -686,39 +687,44 @@ class DataplexCreateOrUpdateDataQualityScanOperator(GoogleCloudBaseOperator):
             impersonation_chain=self.impersonation_chain,
         )
 
-        self.log.info("Creating Dataplex Data Quality scan %s", self.data_scan_id)
-        try:
-            operation = hook.create_data_scan(
-                project_id=self.project_id,
-                region=self.region,
-                data_scan_id=self.data_scan_id,
-                body=self.body,
-                retry=self.retry,
-                timeout=self.timeout,
-                metadata=self.metadata,
-            )
-            hook.wait_for_operation(timeout=self.timeout, operation=operation)
-            self.log.info("Dataplex Data Quality scan %s created successfully!", self.data_scan_id)
-        except AlreadyExists:
-            self.log.info("Dataplex Data Quality scan already exists: %s", {self.data_scan_id})
-
-            operation = hook.update_data_scan(
-                project_id=self.project_id,
-                region=self.region,
-                data_scan_id=self.data_scan_id,
-                body=self.body,
-                update_mask=self.update_mask,
-                retry=self.retry,
-                timeout=self.timeout,
-                metadata=self.metadata,
-            )
-            hook.wait_for_operation(timeout=self.timeout, operation=operation)
-            self.log.info("Dataplex Data Quality scan %s updated successfully!", self.data_scan_id)
-        except GoogleAPICallError as e:
-            raise AirflowException(f"Error creating Data Quality scan {self.data_scan_id}", e)
+        if self.update_mask is not None:
+            self._update_data_scan(hook)
+        else:
+            self.log.info("Creating Dataplex Data Quality scan %s", self.data_scan_id)
+            try:
+                operation = hook.create_data_scan(
+                    project_id=self.project_id,
+                    region=self.region,
+                    data_scan_id=self.data_scan_id,
+                    body=self.body,
+                    retry=self.retry,
+                    timeout=self.timeout,
+                    metadata=self.metadata,
+                )
+                hook.wait_for_operation(timeout=self.timeout, operation=operation)
+                self.log.info("Dataplex Data Quality scan %s created successfully!", self.data_scan_id)
+            except AlreadyExists:
+                self._update_data_scan(hook)
+            except GoogleAPICallError as e:
+                raise AirflowException(f"Error creating Data Quality scan {self.data_scan_id}", e)
 
         return self.data_scan_id
 
+    def _update_data_scan(self, hook: DataplexHook):
+        self.log.info("Dataplex Data Quality scan already exists: %s", {self.data_scan_id})
+        operation = hook.update_data_scan(
+            project_id=self.project_id,
+            region=self.region,
+            data_scan_id=self.data_scan_id,
+            body=self.body,
+            update_mask=self.update_mask,
+            retry=self.retry,
+            timeout=self.timeout,
+            metadata=self.metadata,
+        )
+        hook.wait_for_operation(timeout=self.timeout, operation=operation)
+        self.log.info("Dataplex Data Quality scan %s updated successfully!", self.data_scan_id)
+
 
 class DataplexGetDataQualityScanOperator(GoogleCloudBaseOperator):
     """
@@ -1003,7 +1009,7 @@ class DataplexRunDataQualityScanOperator(GoogleCloudBaseOperator):
 
     def execute_complete(self, context, event=None) -> None:
         """
-        Callback for when the trigger fires - returns immediately.
+        Act as a callback for when the trigger fires - returns immediately.
 
         Relies on trigger to throw an exception, otherwise it assumes execution was
         successful.
@@ -1067,7 +1073,7 @@ class DataplexGetDataQualityScanResultOperator(GoogleCloudBaseOperator):
         is available.
     """
 
-    template_fields = ("project_id", "data_scan_id", "impersonation_chain")
+    template_fields = ("project_id", "data_scan_id", "impersonation_chain", "job_id")
 
     def __init__(
         self,
@@ -1180,7 +1186,7 @@ class DataplexGetDataQualityScanResultOperator(GoogleCloudBaseOperator):
 
     def execute_complete(self, context, event=None) -> None:
         """
-        Callback for when the trigger fires - returns immediately.
+        Act as a callback for when the trigger fires - returns immediately.
 
         Relies on trigger to throw an exception, otherwise it assumes execution was
         successful.
@@ -1578,7 +1584,7 @@ class DataplexRunDataProfileScanOperator(GoogleCloudBaseOperator):
 
     def execute_complete(self, context, event=None) -> None:
         """
-        Callback for when the trigger fires - returns immediately.
+        Act as a callback for when the trigger fires - returns immediately.
 
         Relies on trigger to throw an exception, otherwise it assumes execution was
         successful.
@@ -1713,7 +1719,7 @@ class DataplexGetDataProfileScanResultOperator(GoogleCloudBaseOperator):
 
     def execute_complete(self, context, event=None) -> None:
         """
-        Callback for when the trigger fires - returns immediately.
+        Act as a callback for when the trigger fires - returns immediately.
 
         Relies on trigger to throw an exception, otherwise it assumes execution was
         successful.
